==========
Yorkshire4
==========

In 1982, my parents bought a Commodore 64 for our family. At first, I just
played games - from a cartridge, or from a tape drive. But I soon understood
that this machine could be *programmed*, which meant you could write your own
games. But what game should I write?

Luckily, my local library had the answer, in the form of books with titles
like "Computer Space Games" and "Write your own Adventure Programs". These
books contained full code listings for simple games. Each game was illustrated
with vibrant pictures that fired the imagination... which was a good thing,
because the games themselves were incredibly simplistic, and usually text
based.

But, the promise of a game where you blew up space aliens or slew a dragon was
enough to convince you carefully transcribe the code, line by line... until
you had a game that you had written all by yourself!!

And thus was set the direction for my entire career.

I'm not the only person who had this experience.. Many of today's tech
professionals were inspired by the Usborne computing books they read as
children. So much so, that Usborne has `provided PDFs of those old programming
books of my youth
<https://usborne.com/browse-books/features/computer-and-coding-books>`__.

Today, I have children of my own. Instead of huddling over a Commodore 64 with
it's "38911 BASIC BYTES FREE", they have phones, tablets and laptops, each of
which have several orders of magnitude more computing power.

And, I'm a part of a worldwide computer language community - the `Python
community <https://python.org>`__. Python is a marvellous language - simple and
clear enough to be used as a teaching language, but powerful enough to be used
to drive high traffic websites like Instagram, for scientific data analysis,
for financial trading, and much more.

This project is my attempt to resurrect this period of my youth, and bring to
my children (and others) the joy that I had as a 7 year old, writing games -
but in the language that I now use as an adult.

.. toctree::
   :maxdepth: 2
   :glob:

   getting-started
   books/index
   contributing/index
   colophon
